==> webkit2gtk_2.14.0.orig.tar.xz: webkitgtk-2.14.0/Source/WebKit2/UIProcess/gtk/WebInspectorClientGtk.h <==
/*
 * Copyright (C) 2012 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebInspectorClientGtk_h
#define WebInspectorClientGtk_h

#include "APIClient.h"
#include "WKInspectorClientGtk.h"

#include <wtf/text/WTFString.h>

namespace API {
class Object;

template<> struct ClientTraits<WKInspectorClientGtkBase> {
    typedef std::tuple<WKInspectorClientGtkV0> Versions;
};
}

namespace WebKit {

class WebInspectorProxy;

class WebInspectorClientGtk : public API::Client<WKInspectorClientGtkBase> {
public:
    bool openWindow(WebInspectorProxy*);
    void didClose(WebInspectorProxy*);
    bool bringToFront(WebInspectorProxy*);
    void inspectedURLChanged(WebInspectorProxy*, const String& url);
    bool attach(WebInspectorProxy*);
    bool detach(WebInspectorProxy*);
    void didChangeAttachedHeight(WebInspectorProxy*, unsigned height);
    void didChangeAttachedWidth(WebInspectorProxy*, unsigned width);
    void didChangeAttachAvailability(WebInspectorProxy*, bool available);
};

} // namespace WebKit

#endif // WebInspectorClientGtk_h

==> webkit2gtk_2.16.6.orig.tar.xz: webkitgtk-2.16.6/Source/WebKit2/UIProcess/gtk/WebInspectorClientGtk.h <==
/*
 * Copyright (C) 2012 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "APIClient.h"
#include "WKInspectorClientGtk.h"
#include <wtf/text/WTFString.h>

namespace API {
class Object;

template<> struct ClientTraits<WKInspectorClientGtkBase> {
    typedef std::tuple<WKInspectorClientGtkV0> Versions;
};
}

namespace WebKit {

class WebInspectorProxy;

class WebInspectorClientGtk : public API::Client<WKInspectorClientGtkBase> {
public:
    bool openWindow(WebInspectorProxy*);
    void didClose(WebInspectorProxy*);
    bool bringToFront(WebInspectorProxy*);
    void inspectedURLChanged(WebInspectorProxy*, const String& url);
    bool attach(WebInspectorProxy*);
    bool detach(WebInspectorProxy*);
    void didChangeAttachedHeight(WebInspectorProxy*, unsigned height);
    void didChangeAttachedWidth(WebInspectorProxy*, unsigned width);
    void didChangeAttachAvailability(WebInspectorProxy*, bool available);
};

} // namespace WebKit
